//--------------------------------------------------------------
// Press F1 to get help about using script.
// To access an object that is not located in the current class, start the call with Globals.
// When using events and timers be cautious not to generate memoryleaks,
// please see the help for more information.
//---------------------------------------------------------------

/*
*******************************************************************
All examples in this support document are only intended
to improve understanding of the functionality and 
handling of the equipment. 
Beijer Electronics Incorporated cannot assume any liability if these
examples are used in real applications.
In view of the wide range of applications for this 
equipment, users must acquire sufficient knowledge 
themselves in order to ensure that it is correctly used in 
their specific application. Persons responsible for the 
application and the equipment must themselves 
ensure that each application is in compliance with all 
relevant requirements, standards and legislation in 
respect to configuration and safety.
Beijer Electronics Incorporated will accept no liability for any 
damage incurred during the installation or use of this 
equipment.
Beijer Electronics Incorporated prohibits all modification, changes
or conversion of the equipment.

This sample has dependencies to internal iX-functions. It has been 
tested with version 2.xx. There are no guarantees that this sample 
will compile or work as intended in future versions of iX since the 
internal architecture may be changed.
*******************************************************************
*/

namespace Neo.ApplicationFramework.Generated
{
	using System.Windows.Forms;
	using System;
	using System.Drawing;
	using Neo.ApplicationFramework.Tools;
	using Neo.ApplicationFramework.Common.Graphics.Logic;
	using Neo.ApplicationFramework.Controls;
	using Neo.ApplicationFramework.Interfaces;
	
    
	public partial class SchedulerUtils
	{
		//Instance varibles
		//Get the Scheduler collection to work with contained job objects
		Tools.Scheduler.SchedulerJobs jobs = new Tools.Scheduler.SchedulerJobs(Globals.Scheduler);
				
		/// <summary>
		/// GetSchedulerJobInfo 
		/// Returns formatted string of actual Job settings.
		/// </summary>
		/// <param name="job">Interfaces.IScheduler</param>
		/// <returns>string</returns>
		public string GetSchedulerJobInfo(Interfaces.ISchedulerJob job)
		{
			string info = "Name: " + job.Name + Environment.NewLine;
			info = info + "Period: " + job.Period.ToString() + Environment.NewLine;
			info = info + "Start Date: " + Globals.Scheduler.IndoorLights.StartDate.ToString() + Environment.NewLine;
			info = info + "Start Time: " + Globals.Scheduler.IndoorLights.StartTime.ToString() + Environment.NewLine;
			TimeSpan durationText = Globals.Scheduler.IndoorLights.Duration;
			info = info + "Duration:" + durationText.ToString() + Environment.NewLine;
			return info;
		}
		
		/// <summary>
		/// GetSchedulerJobs
		/// Retrieves a string array contaning Job Names with avaliable Jobs
		/// </summary>
		/// <param name="JobNames">string[] of jobnames</param>
		/// <returns></returns>
		public void GetSchedulerJobs(ref string[]JobNames)
		{
			//Move jobs to container to work with
			jobs = Globals.Scheduler.SchedulerJobs;
			
			//Code below shows how to extract a given (index) job within the collection 
			//Interfaces.ISchedulerJob job = jobs[0];
						
			Array.Resize(ref JobNames, jobs.Count);
			
			//Iterates through the collection and gets the names of each avaliable schedulerjob
			int i = 0;
			foreach (Interfaces.ISchedulerJob job in jobs)
			{
				JobNames[i] = (job.Name);
				i++;
			}
		}

		/// <summary>
		/// GetSchedulerJobByIndex
		/// Returns the job ny a given index
		/// </summary>
		/// <param name="index">int index zerobased</param>
		/// <returns>Interfaces.ISchedulerJob</returns>
		public Interfaces.ISchedulerJob GetSchedulerJobByIndex(int index)
		{
			
			//Move jobs to container to work with
			jobs = Globals.Scheduler.SchedulerJobs;
			//...and return back to inkvoking method
			//Check if given index is within bounds
			if ((index >= 0) && (index < jobs.Count)) 
			{
				return jobs[index];
			}
			else
			{
				throw new Exception("Passed in index is out off bounds");	
			}
		}

		/// <summary>
		/// SetStartTime
		/// Sets starttime of passed in object with the passed as a string
		/// Exception: When failing to parse the input string
		/// Messagebox with error message
		/// </summary>
		/// <param name="Job">Interfaces.IScheduler</param>
		/// <param name="NewStartTime">string Start Time</param>
		/// <returns>void</returns>
		public void SetStartTime(Interfaces.ISchedulerJob Job, string NewStartTime)
		{
			try{
				Job.StartTime = DateTime.Parse(NewStartTime, System.Globalization.CultureInfo.InvariantCulture);
			}
			catch(Exception ex)
			{
				ShowErrorMessage(ex.Message);
			}
		}

		/// <summary>
		/// SetDuration
		/// Sets the duration
		/// 
		/// Exception: When failing to parse the input string
		/// Messagebox with error message
		/// </summary>
		/// <param name="Job">Interfaces.ISchedulerJob</param>
		/// <param name="NewDuration">string duration</param>
		/// <returns>void</returns>
		public void SetDuration(Interfaces.ISchedulerJob Job, string NewDuration)
		{
			// Add "0." to represent days
			// See msdn.com form more information about TimeSpan.Parse
			string newDuration = "0." + NewDuration;
			try
			{
				Job.Duration = TimeSpan.Parse(newDuration);
			}
			catch(Exception ex)
			{
				ShowErrorMessage(ex.Message);
			}
		}

		private void ShowErrorMessage(string ErrorMessage)
		{
			MessageBox.Show(ErrorMessage);

		}
	}
}
