//--------------------------------------------------------------
// Press F1 to get help about using script.
// To access an object that is not located in the current class, start the call with Globals.
// When using events and timers be cautious not to generate memoryleaks,
// please see the help for more information.
//---------------------------------------------------------------

namespace Neo.ApplicationFramework.Generated
{
	using System.Windows.Forms;
	using System;
	using System.Drawing;
	using Neo.ApplicationFramework.Tools;
	using Neo.ApplicationFramework.Common.Graphics.Logic;
	using Neo.ApplicationFramework.Controls;
	using Neo.ApplicationFramework.Interfaces;
	
    
	public partial class Screen2
	{
		//Instance Variables
		//Improvement, thisboject should reside as a pobject inside the
		//scriptmodule instead. Accessible through a property.
		Interfaces.ISchedulerJob m_job;
		
		#region Events
		/// <summary>
		/// When screen opens the listbox is populated with
		/// avaliable Scheduler Jobs
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		/// <returns></returns>
		void Screen2_Opened(System.Object sender, System.EventArgs e)
		{
			//Populate a ComboBox with availiable Scheduler jobs
			GetSchedulerJobsNames();
		}
		
		/// <summary>
		/// Update controls as a new selection is made by the listbox
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		/// <returns></returns>
		void ComboBoxSchedulerJobsAvaliable_SelectionChanged(System.Object sender, System.EventArgs e)
		{
			UpdateActualSettingsTextBox();
			UpdateControls();
		}
		
		/// <summary>
		/// Set new timevalues to selected Scheduler Job
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		/// <returns></returns>
		void ButtonSetNewTimeValues_Click(System.Object sender, System.EventArgs e)
		{
			SetNewTimeSettings();
			UpdateActualSettingsTextBox();
		}
		#endregion Events
		
		
		#region Helper Methods
		
		/// <summary>
		/// Updates controls on theform
		/// </summary>
		/// <returns>void</returns>
		private void UpdateControls()
		{
			RefreshJob();
			this.AnalogNumericStartTime.Value = m_job.StartTime.ToString();
			this.AnalogNumericDuration.Value = m_job.Duration.ToString();
		}

		/// <summary>
		/// Updates the textbox content with selected Scheduler Job actual settings.
		/// </summary>
		/// <returns>void</returns>
		private void UpdateActualSettingsTextBox()
		{
			this.TextBoxSchedulerSettings.Text = string.Empty;
			this.TextBoxSchedulerSettings.Text = Globals.SchedulerUtils.GetSchedulerJobInfo(GetJob(this.ComboBoxSchedulerJobsAvaliable.SelectedIndex));
		}

		/// <summary>
		/// Sets changes for starttime and duration
		/// </summary>
		/// <returns></returns>
		private void SetNewTimeSettings()
		{
			Globals.SchedulerUtils.SetStartTime(m_job, this.AnalogNumericStartTime.Value.ToString());
			Globals.SchedulerUtils.SetDuration(m_job, this.AnalogNumericDuration.Value.ToString());
		}
		
		/// <summary>
		/// Helper Method to populate listbox with the avaliable jobnames
		/// </summary>
		/// <returns></returns>
		private void GetSchedulerJobsNames()
		{
			string[] jobNames = new string[]{};
			Globals.SchedulerUtils.GetSchedulerJobs(ref jobNames);	
			foreach (string jobName in jobNames)
			{
				this.ComboBoxSchedulerJobsAvaliable.Items.Add(jobName);
			}
		}
		
		/// <summary>
		/// Gets job by index
		/// </summary>
		/// <param name="index"></param>
		/// <returns>Interfaces.ISchedulerJob</returns>
		private Interfaces.ISchedulerJob GetJob(int index)
		{
			Interfaces.ISchedulerJob job = Globals.SchedulerUtils.GetSchedulerJobByIndex(this.ComboBoxSchedulerJobsAvaliable.SelectedIndex);
			return job;
		}
		
		/// <summary>
		/// Assign the selected job to the instance variable to ensure that the container 
		/// hold the selected object.
		/// </summary>
		/// <returns></returns>
		private void RefreshJob()
		{
			m_job = Globals.SchedulerUtils.GetSchedulerJobByIndex(this.ComboBoxSchedulerJobsAvaliable.SelectedIndex);
		}
		#endregion Helper Methods
		
		void ButtonResetTags_Click(System.Object sender, System.EventArgs e)
		{
			Globals.Tags.IndoorLightsOn.Value = false;
			Globals.Tags.GardenLightsOn.Value = false;
			Globals.Tags.WaterValveOpen.Value = false;
		}
	}
}
